@@ -149,7 +149,7 @@ impl AdminInterfaceApi for RealAdminInterfaceApi {
                     let InstallAppDnaPayload {
                         hash,
                         membrane_proof,
-                        nick,
+                        role_id,
                     } = dna_payload;
 
                     // confirm that hash has been installed
@@ -161,7 +161,7 @@ impl AdminInterfaceApi for RealAdminInterfaceApi {
                         )));
                     }
                     let cell_id = CellId::from((hash, agent_key.clone()));
-                    ConductorApiResult::Ok((InstalledCell::new(cell_id, nick), membrane_proof))
+                    ConductorApiResult::Ok((InstalledCell::new(cell_id, role_id), membrane_proof))
                 });
 
                 // Join all the install tasks
@@ -297,6 +297,16 @@ impl AdminInterfaceApi for RealAdminInterfaceApi {
                 let state = self.conductor_handle.dump_cell_state(&cell_id).await?;
                 Ok(AdminResponse::StateDumped(state))
             }
+            DumpFullState {
+                cell_id,
+                dht_ops_cursor,
+            } => {
+                let state = self
+                    .conductor_handle
+                    .dump_full_cell_state(&cell_id, dht_ops_cursor)
+                    .await?;
+                Ok(AdminResponse::FullStateDumped(state))
+            }
             AddAgentInfo { agent_infos } => {
                 self.conductor_handle.add_agent_infos(agent_infos).await?;
                 Ok(AdminResponse::AgentInfoAdded)
