@@ -30,6 +30,8 @@ pub fn call_info(
                             .host_context
                             .workspace()
                             .source_chain()
+                            .as_ref()
+                            .expect("Must have source chain if bindings access is given")
                             .valid_cap_grant(
                                 check_function,
                                 check_agent,
@@ -48,6 +50,8 @@ pub fn call_info(
                             .host_context
                             .workspace()
                             .source_chain()
+                            .as_ref()
+                            .expect("Must have source chain if bindings access is given")
                             .agent_pubkey()
                             .clone();
                         (author.clone(), CapGrant::ChainAuthor(author))
@@ -60,6 +64,8 @@ pub fn call_info(
                     .host_context
                     .workspace()
                     .source_chain()
+                    .as_ref()
+                    .expect("Must have source chain if bindings access is given")
                     .persisted_chain_head(),
                 provenance,
                 cap_grant,
