@@ -14,7 +14,7 @@ use super::error::WorkflowResult;
 use crate::core::queue_consumer::TriggerSender;
 use crate::core::queue_consumer::WorkComplete;
 use holo_hash::*;
-use holochain_p2p::HolochainP2pCellT;
+use holochain_p2p::HolochainP2pDnaT;
 use holochain_state::prelude::*;
 use holochain_types::prelude::*;
 use std::collections::HashMap;
@@ -33,16 +33,16 @@ pub const MIN_PUBLISH_INTERVAL: time::Duration = time::Duration::from_secs(60 *
 
 #[instrument(skip(env, network, trigger_self))]
 pub async fn publish_dht_ops_workflow(
-    env: EnvWrite,
-    network: &(dyn HolochainP2pCellT + Send + Sync),
+    env: DbWrite<DbKindAuthored>,
+    network: &(dyn HolochainP2pDnaT + Send + Sync),
     trigger_self: &TriggerSender,
+    agent: AgentPubKey,
 ) -> WorkflowResult<WorkComplete> {
     let mut complete = WorkComplete::Complete;
-    let to_publish =
-        publish_dht_ops_workflow_inner(env.clone().into(), network.from_agent()).await?;
+    let to_publish = publish_dht_ops_workflow_inner(env.clone().into(), agent).await?;
 
     // Commit to the network
-    tracing::info!("sending {} ops", to_publish.len());
+    tracing::info!("sending to {} basis locations", to_publish.len());
     let mut success = Vec::new();
     for (basis, ops) in to_publish {
         let hashes: Vec<_> = ops.iter().map(|(h, _)| h.clone()).collect();
@@ -83,13 +83,13 @@ pub async fn publish_dht_ops_workflow(
 
 /// Read the authored for ops with receipt count < R
 pub async fn publish_dht_ops_workflow_inner(
-    env: EnvRead,
+    env: DbRead<DbKindAuthored>,
     agent: AgentPubKey,
 ) -> WorkflowResult<HashMap<AnyDhtHash, Vec<(DhtOpHash, DhtOp)>>> {
     // Ops to publish by basis
     let mut to_publish = HashMap::new();
 
-    for op_hashed in publish_query::get_ops_to_publish(agent.clone(), &env).await? {
+    for op_hashed in publish_query::get_ops_to_publish(agent, &env).await? {
         let (op, op_hash) = op_hashed.into_inner();
         // For every op publish a request
         // Collect and sort ops by basis
@@ -113,7 +113,7 @@ mod tests {
     use ::fixt::prelude::*;
     use futures::future::FutureExt;
     use holochain_p2p::actor::HolochainP2pSender;
-    use holochain_p2p::HolochainP2pCell;
+    use holochain_p2p::HolochainP2pDna;
     use holochain_p2p::HolochainP2pRef;
     use observability;
     use rusqlite::Transaction;
@@ -130,14 +130,15 @@ mod tests {
     const RECV_TIMEOUT: Duration = Duration::from_millis(3000);
 
     /// publish ops setup
-    async fn setup<'env>(
-        env: EnvWrite,
+    async fn setup(
+        env: DbWrite<DbKindAuthored>,
         num_agents: u32,
         num_hash: u32,
         panic_on_publish: bool,
     ) -> (
         TestNetwork,
-        HolochainP2pCell,
+        HolochainP2pDna,
+        AgentPubKey,
         JoinHandle<()>,
         tokio::sync::oneshot::Receiver<()>,
     ) {
@@ -158,7 +159,7 @@ mod tests {
                     let op = DhtOp::RegisterAddLink(sig.clone(), link_add.clone());
                     // Get the hash from the op
                     let op_hashed = DhtOpHashed::from_content_sync(op.clone());
-                    mutations::insert_op(txn, op_hashed, true)?;
+                    mutations::insert_op(txn, op_hashed)?;
                 }
                 StateMutationResult::Ok(())
             })
@@ -180,7 +181,7 @@ mod tests {
             test_network_with_events(Some(dna.clone()), Some(author.clone()), filter_events, tx)
                 .await;
         let (tx_complete, rx_complete) = tokio::sync::oneshot::channel();
-        let cell_network = test_network.cell_network();
+        let dna_network = test_network.dna_network();
         let network = test_network.network();
         let mut recv_count: u32 = 0;
         let total_expected = num_agents * num_hash;
@@ -219,13 +220,17 @@ mod tests {
                 .unwrap();
         }
 
-        (test_network, cell_network, recv_task, rx_complete)
+        (test_network, dna_network, author, recv_task, rx_complete)
     }
 
     /// Call the workflow
-    async fn call_workflow(env: EnvWrite, cell_network: HolochainP2pCell) {
+    async fn call_workflow(
+        env: DbWrite<DbKindAuthored>,
+        dna_network: HolochainP2pDna,
+        author: AgentPubKey,
+    ) {
         let (trigger_sender, _) = TriggerSender::new();
-        publish_dht_ops_workflow(env.clone().into(), &cell_network, &trigger_sender)
+        publish_dht_ops_workflow(env.clone().into(), &dna_network, &trigger_sender, author)
             .await
             .unwrap();
     }
@@ -245,14 +250,14 @@ mod tests {
             observability::test_run().ok();
 
             // Create test env
-            let test_env = test_cell_env();
+            let test_env = test_authored_env();
             let env = test_env.env();
 
             // Setup
-            let (_network, cell_network, recv_task, rx_complete) =
+            let (_network, dna_network, author, recv_task, rx_complete) =
                 setup(env.clone(), num_agents, num_hash, false).await;
 
-            call_workflow(env.clone().into(), cell_network).await;
+            call_workflow(env.clone().into(), dna_network, author).await;
 
             // Wait for expected # of responses, or timeout
             tokio::select! {
@@ -299,11 +304,11 @@ mod tests {
             observability::test_run().ok();
 
             // Create test env
-            let test_env = test_cell_env();
+            let test_env = test_authored_env();
             let env = test_env.env();
 
             // Setup
-            let (_network, cell_network, recv_task, _) =
+            let (_network, dna_network, author, recv_task, _) =
                 setup(env.clone(), num_agents, num_hash, true).await;
 
             // Update the authored to have complete receipts
@@ -316,7 +321,7 @@ mod tests {
                 .unwrap();
 
             // Call the workflow
-            call_workflow(env.clone().into(), cell_network).await;
+            call_workflow(env.clone().into(), dna_network, author).await;
 
             // If we can wait a while without receiving any publish, we have succeeded
             tokio::time::sleep(Duration::from_millis(
@@ -356,7 +361,9 @@ mod tests {
                 observability::test_run().ok();
 
                 // Create test env
-                let test_env = test_cell_env();
+                let test_env = test_authored_env();
+                let keystore = holochain_state::test_utils::test_keystore();
+                let dht_env = test_dht_env();
                 let env = test_env.env();
                 let zome = fixt!(Zome);
 
@@ -366,14 +373,15 @@ mod tests {
                     _ => false,
                 };
                 let (tx, mut recv) = tokio::sync::mpsc::channel(10);
+                let author = fake_agent_pubkey_1();
                 let test_network = test_network_with_events(
                     Some(dna.clone()),
-                    Some(fake_agent_pubkey_1()),
+                    Some(author.clone()),
                     filter_events,
                     tx,
                 )
                 .await;
-                let cell_network = test_network.cell_network();
+                let dna_network = test_network.dna_network();
 
                 // Setup data
                 let original_entry = fixt!(Entry);
@@ -389,7 +397,9 @@ mod tests {
                 let eu_entry_type = entry_type_fixt.next().unwrap();
 
                 // Genesis and produce ops to clear these from the chains
-                fake_genesis(env.clone()).await.unwrap();
+                fake_genesis(env.clone(), dht_env.env(), keystore.clone())
+                    .await
+                    .unwrap();
                 env.conn()
                     .unwrap()
                     .execute("UPDATE DhtOp SET receipts_complete = 1", [])
@@ -397,9 +407,14 @@ mod tests {
                 let author = fake_agent_pubkey_1();
 
                 // Put data in elements
-                let source_chain = SourceChain::new(env.clone().into(), author.clone())
-                    .await
-                    .unwrap();
+                let source_chain = SourceChain::new(
+                    env.clone().into(),
+                    dht_env.env(),
+                    keystore.clone(),
+                    author.clone(),
+                )
+                .await
+                .unwrap();
                 // Produces 3 ops but minus 1 for store entry so 2 ops.
                 let original_header_address = source_chain
                     .put(
@@ -430,7 +445,7 @@ mod tests {
                     .await
                     .unwrap();
 
-                source_chain.flush(&cell_network).await.unwrap();
+                source_chain.flush(&dna_network).await.unwrap();
                 let (entry_create_header, entry_update_header) = env
                     .conn()
                     .unwrap()
@@ -580,7 +595,7 @@ mod tests {
                     }
                 }
 
-                call_workflow(env.clone().into(), cell_network).await;
+                call_workflow(env.clone().into(), dna_network, author).await;
 
                 // Wait for expected # of responses, or timeout
                 tokio::select! {
